function RK4()
    %
    clc
    
    ButcherTableau = [ ...
        0,    0  , 0  , 0  , 0; ...
        0.5,  0.5, 0  , 0  , 0; ...
        0.5,  0  , 0.5, 0  , 0; ...
        1  ,  0  , 0  , 1  , 0; ...
        %
        0,    1/6, 1/3, 1/3, 1/6];
    %
    m = 100;      % Anzahl innerer Punkte
    tIter = 2000;
    T = 0.1;
    
    h = 1/(m+1); % Aufloesung x-Achse
    xInner = linspace(h,1-h,m)';  % Gitter x-Achse; innere Punkte
    %
    t = linspace(0,T,tIter+1);    % Gitter Zeitachse
    dt = t(2)-t(1);
    
    A = systemMatrix(m);      % Systemmatrix
    y0 = sin(3*pi*xInner).^2; % Anfangswerte
    
    y = RK_explicit(A,y0,tIter,dt,ButcherTableau);
    
    figure
    mesh([0;xInner;1],t(1:20:end),y(:,1:20:end)')
    xlabel('x')
    ylabel('t')
end

function A = systemMatrix(m)
    A = (m+1)^2 * spdiags([ones(m,1),-2*ones(m,1),1*ones(m,1)], ...
                        [-1,0,1],m,m);
end

function k = compute_ki(A,yn,dt,beta,N)
    k = zeros(length(yn),N);
    for i = 1:N
        k(:,i) = A*(yn + dt*k*beta(i,:)');
    end
end

function y = RK_explicit(A,y0,tIter,dt,ButcherTableau)
    % alpha = ButcherTableau(1:end-1,1);
    beta =  ButcherTableau(1:end-1,2:end);
    gamma = ButcherTableau(end,2:end);
    N = length(gamma);  % Anzahl Stufen des Verfahrens
    %
    y = zeros(length(y0)+2,tIter+1); % init
    y(2:end-1,1) = y0;
    yn = y0;
    %
    for n = 1:tIter
        % Werte Inkrementfunktion aus.
        k = compute_ki(A,yn,dt,beta,N);
        phi = k*gamma';
        %
        yn = yn + dt*phi;  % Iteriere
        %
        y(2:end-1,n+1) = yn;
    end
end